<?xml version="1.0"?>
<xsl:stylesheet xmlns:cfg="http://cdox.sf.net/schema/configuration"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		extension-element-prefixes="cfg"
		version="1.0">

  <xsl:output method="html"
	      encoding="iso-8859-1"
	      doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"
	      indent="yes"/>

  <xsl:strip-space elements="*"/>

  <!--
  These parameters MUST be set. The homepage parameter should be a relative link
  to the homepage of the project.
  -->
  <xsl:param name="language"/>
  <xsl:param name="homepage"/>

  <!--
  Root template.
  -->
  <xsl:template match="/cfg:configuration">
    <html>
      <head>
	<title><xsl:value-of select="cfg:description[lang($language)]/@title"/></title>
      </head>
      <!--
      Some CSS attributes.
      -->
      <style type="text/css">
	table {
	border: solid black;
	}
	td {
	padding: 1px 1px 1px 1px;
	border: solid black 1px;
	}
	a:link{
	color: #cc0000;
	}
	a:active{
	color: #ff0000;
	}
	a:visited{
	color: #660000;
	}
	a:hover{
	background-color: black;
	color: #ffffff;
	}
      </style>
      <body>
	<!--
	Outputs the available languages.
	-->
	<div style="position: absolute; top: 3mm; left:3mm; width: 15%; padding:
	     3mm 3mm 3mm 3mm; border: groove black; background: lightgray;">
	  <xsl:text>Languages:</xsl:text><br/>
	  <xsl:for-each select="cfg:description">
	    <xsl:apply-templates select="."/>
	  </xsl:for-each>
	  <hr/>
	  <a href="{$homepage}">Homepage</a>
	</div>
	<!--
	Outputs the description text, then the pages.
	-->
	<div style="position: absolute; top: 3mm; left: 20%; width: 76%; padding:
	     3mm 3mm 3mm 3mm; border: groove black; background: lightgray;
	     min-height: 80%;">
	  <h1 style="text-align: center;">
	    <xsl:value-of select="cfg:description[lang($language)]/@title"/>
	  </h1>
	  <p>
	    <xsl:value-of select="cfg:description[lang($language)]"/>
	  </p>
	  <xsl:apply-templates select="//cfg:page"/>
	</div>
      </body>
    </html>
  </xsl:template>

  <!--
  Extracts the languages.
  -->
  <xsl:template match="cfg:description">
    <xsl:choose>
      <xsl:when test="lang($language)">
	<div style="padding: 1mm 1mm 1mm 1mm; margin: 1mm 1mm 1mm 1mm;
	     border: solid darkblue;">
	  <xsl:value-of select="@title"/><br/>
	</div>
      </xsl:when>
      <xsl:otherwise>
	<a href="configuration.{@xml:lang}.html">
	  <xsl:value-of select="@title"/>
	</a><br/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--
  Is processed for each page of configuration.
  -->
  <xsl:template match="cfg:page">
    <h4>
      <xsl:value-of select="cfg:title[lang($language)]"/>
    </h4>
    <xsl:apply-templates select="cfg:separator"/>
  </xsl:template>

  <!--
  Separators.
  -->
  <xsl:template match="cfg:separator">
    <div style="alignment: center;">
      <table>
	<tr>
	  <th style="column-span: 2;">
	    <xsl:value-of select="cfg:text[lang($language)]"/>
	  </th>
	</tr>
	<xsl:for-each select="child::*">
	  <xsl:apply-templates select="."/>
	</xsl:for-each>
      </table>
      <br/>
    </div>
  </xsl:template>

  <!--
  Outputs a table row with the hint in the first cell and the default value in
  the second.
  -->
  <xsl:template match="cfg:keystroke">
    <tr>
      <td>
	<xsl:value-of select="cfg:hint[lang($language)]"/>
      </td>
      <td>
	<xsl:value-of select="cfg:default/@modifier"/>
	<xsl:if test="cfg:default/@modifier!=''">
	  <xsl:text>+</xsl:text>
	</xsl:if>
	<xsl:value-of select="cfg:default/@key"/>
      </td>
    </tr>
  </xsl:template>

  <!--
  Outputs a table row with the hint in the first cell and the default value in
  the second.
  -->
  <xsl:template match="cfg:yesno">
    <tr>
      <td>
	<xsl:value-of select="cfg:hint[lang($language)]"/>
      </td>
      <td>
	<xsl:value-of select="cfg:default/@value"/>
      </td>
    </tr>
  </xsl:template>

  <!--
  Language setting. Not yet localized.
  -->
  <xsl:template match="cfg:language">
    <tr>
      <td>
	<xsl:text>Choose your language.</xsl:text>
      </td>
      <td>
	<xsl:text>None.</xsl:text>
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="cfg:title">
    <!-- Emtpy template. -->
  </xsl:template>

  <xsl:template match="cfg:text">
    <!-- Emtpy template. -->
  </xsl:template>

</xsl:stylesheet>
