<?xml version="1.0"?>
<xsl:stylesheet xmlns:doc="http://sammael.tabu.stw-bonn.de/schema/documentation"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		extension-element-prefixes="doc"
		version="1.0">

  <xsl:output method="html"
	      encoding="iso-8859-1"
	      doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"
	      indent="yes"/>

  <xsl:strip-space elements="*"/>

  <!--
  These parameters MUST be set. The stylesheet is designed to be used with every
  combination of language/topic to generate one static page each. The homepage
  parameter generates a link with the text "Homepage". This should be a relative
  link.
  -->
  <xsl:param name="language"/>
  <xsl:param name="topic"/>
  <xsl:param name="homepage"/>
  <xsl:param name="configuration"/>
  <xsl:param name="configurationname"/>

  <!--
  Root template.
  -->
  <xsl:template match="/doc:documentation">
    <html>
      <head>
	<title><xsl:value-of select="doc:language[lang($language)]/@title"/></title>
      </head>
      <body>
	<style type="text/css">
	  a:link{
	  color: #cc0000;
	  }
	  a:active{
	  color: #ff0000;
	  }
	  a:visited{
	  color: #660000;
	  }
	  a:hover{
	  background-color: black;
	  color: #ffffff;
	  }
	</style>
	<div style="position: absolute; top: 3mm; left:3mm; width: 15%; padding:
	     3mm 3mm 3mm 3mm; border: groove black; background: #c0c0c0;">
	  <!--
	  This is the navigation bar at the left.
	  -->
	  <xsl:text>Topics:</xsl:text><br/>
	  <xsl:choose>
	    <!--
	    If there are no subtopics, the topics at the same level are used for
	    the navigation bar. For the parameter see the doc:topic template.
	    -->
	    <xsl:when test="count(.//doc:topic[../@id=$topic and
		      lang($language)])=0">
	      <xsl:apply-templates select=".//doc:topic[@id=$topic]/../doc:topic[lang($language)]">
		<xsl:with-param name="navigation" select="nav"/>
	      </xsl:apply-templates>
	    </xsl:when>
	    <!--
	    This one selects the subtopics for the navigation bar.
	    -->
	    <xsl:otherwise>
	      <xsl:apply-templates select=".//doc:topic[../@id=$topic and
				   lang($language)]"/>
	    </xsl:otherwise>
	  </xsl:choose>
	  <!--
	  Outputs the available languages.
	  -->
	  <hr/>
	  <xsl:text>Languages:</xsl:text><br/>
	  <xsl:for-each select="doc:language">
	    <xsl:apply-templates select="."/>
	  </xsl:for-each>
	  <hr/>
	  <xsl:if test="not(not($configuration))">
	    <a href="{$configuration}"><xsl:value-of select="$configurationname"/></a><br/>
	  </xsl:if>
	  <a href="{$homepage}">Homepage</a>
	</div>
	<!--
	Outputs the selected topic.
	-->
	<xsl:apply-templates select=".//doc:topic[@id=$topic and
			     lang($language)]"/>
      </body>
    </html>
  </xsl:template>

  <!--
  Simple language template.
  -->
  <xsl:template match="doc:language">
    <xsl:choose>
      <xsl:when test="lang($language)">
	<div style="padding: 1mm 1mm 1mm 1mm; margin: 1mm 1mm 1mm 1mm;
	     border: solid darkblue;">
	  <xsl:value-of select="@title"/><br/>
	</div>
      </xsl:when>
      <xsl:otherwise>
	<a href="{$topic}.{@xml:lang}.html">
	  <xsl:value-of select="@title"/>
	</a><br/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--
  Outputs either the actual topic as complete, or outputs the topic as link (as
  used by the navigation bar). If a parameter navigation is passed with the
  value "nav", the topic's name is outputted with a <br> tag (also used by the
  navigation bar).
  -->
  <xsl:template match="doc:topic">
    <xsl:param name="navigation"/>
    <xsl:choose>
      <xsl:when test="@id=$topic">
	<xsl:choose>
	  <xsl:when test="$navigation!='nav'">
	    <div style="position: absolute; top: 3mm; left: 20%; width: 76%; border:
		 groove black; background: #c0c0c0; padding: 3mm 3mm 3mm 3mm;
		 min-height: 92%;">
	      <!--
	      The next one does the "history" at the top of the topic.
	      -->
	      <div style="border: solid black; padding: 2mm 2mm 2mm 2mm;">
		<a href="{/doc:documentation/@default}.{$language}.html">
		  <xsl:value-of select="//doc:topic[@id=/doc:documentation/@default
				and lang($language)]/@name"/>
		</a>
		<xsl:text> / </xsl:text>
		<xsl:for-each select="ancestor::doc:topic">
		  <a href="{@id}.{$language}.html"><xsl:value-of select="@name"/></a>
		  <xsl:text> / </xsl:text>
		</xsl:for-each>
		<xsl:value-of select="@name"/>
	      </div>
	      <hr/>
	      <xsl:apply-templates select="doc:para"/>
	    </div>
	  </xsl:when>
	  <xsl:otherwise>
	    <div style="padding: 1mm 1mm 1mm 1mm; margin: 1mm 1mm 1mm 1mm;
		 border: solid darkblue;">
	      <xsl:value-of select="@name"/><br/>
	    </div>
	  </xsl:otherwise>
	</xsl:choose>
      </xsl:when>
      <xsl:otherwise>
	<a href="{@id}.{$language}.html">
	  <xsl:value-of select="@name"/>
	</a><br/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--
  Copies everything below the para element and inserts a headline if the title
  attributes exists.
  Work needed: copying of the child nodes inserts a xmlns attribute (if there
  exist some).
  -->
  <xsl:template match="doc:para">
    <xsl:if test="count(@title)!=0">
      <h4><xsl:value-of select="@title"/></h4>
    </xsl:if>
    <xsl:copy-of select="child::node()"/>
    <br/>
  </xsl:template>

</xsl:stylesheet>
